---
title: What is Open Science About?
author: Peter Baumgartner
date: '2019-06-12'
categories:
  - open-science
  - theory
tags:
  - definition
  - taxonomy
lastmod: '2019-06-23'
summary: 'By discussing different definitions of ‘Open Science’ quoted in the
  literature, the post develops a particular perspective: We argue that openness must
  include not only scientific findings but also the process of knowledge creation.
  The article is the first of a series and contrasts a holistic understanding of Open
  Science with the concepts of eScience, Cyberscience or Science 2.0, Libre Science
  and Open respective Libre Knowledge.'
slug: what-is-open-science-about
commentable: true
draft: no
---

## The double meaning of 'Open Science'

To understand the challenges Open Science poses to civil society, scientists and the public alike have to focus on the double meaning of this term. On the one hand, it refers to a movement to make scientific knowledge publicly accessible for everybody, and on the other hand, it strives for open procedures in the knowledge creation itself.

This second aspect ("to strive for open procedures in the knowledge creation") is often not included in the definition of Open Science, or at least the significance of this goal is not appropriately valued. The following quotes illustrate our claim that the process facet of Open Science is frequently underdeveloped.

> Open science is the movement to make scientific research (including publications, data, physical samples, and software) and its dissemination accessible to all levels of an inquiring society, amateur or professional. [Wikipedia](https://en.wikipedia.org/w/index.php?title=Open_science&oldid=900178688)

> Open data and content can be freely used, modified, and shared by anyone for any purpose. [The Open Definition](https://opendefinition.org/)

The first example is from Wikipedia, the most popular website featuring not only free content but also supporting community building for Open Knowledge. The immediately following quote is the short version of the famous <em>Open Definition</em> by Open Knowledge Foundation, a global non-profit organization, dedicated to help civil society groups to access and use data to solve social problems.

Accountable for not mentioning of the process components of Open Science is not the compact form of these two definitions, as can be seen by a more exhaustive wording in the next citation. The following third example uses the term *Open Knowledge* instead of Open Science, but as explained further below we will not only show the equivalence of these two notions but argue that Open Knowledge is even the better concept.

> 'Open knowledge' is any content, information or data that people are free to use, re-use and redistribute --- without any legal, technological or social restriction. We detail exactly what openness entails in the Open Knowledge Definition. The main principles are:

> -   Free and open **access** to the material
> -   Freedom to **redistribute** the material
> -   Freedom to **reuse** the material
> -   No restriction of the above based on who someone is (such as their job) or where they are (such as their country of residence) or their field of endeavour (including whether they are working on a commercial or non-commercial project)

> **Open knowledge** is what open data becomes when it's **useful, usable and used** - not just that some data is open and can be freely used, but that it is useful -- accessible, understandable, meaningful, and able to help someone solve a real problem.

> So open knowledge is empowering -- it helps us effect change and improve the world.

Clearly, this an applaudable quote! It targets to foster social responsibility and civil society. But look at it in more detail: The focus is on 'material' (= product), there are no references to the **generation processes** of material. Taken verbatim it does not necessarily include *Open Research Workflow*, *Open Methodology*, *Open (Peer) Review* or *Open Scholarship*, to name just a few notions relevant in the making of knowledge. Knowledge does not sit around and wait to be picked up but emerges in a (controversial) construction process. (Latour, 2007)^\[Latour, B. (2007). Reassembling the Social: An Introduction to Actor-Network-Theory (New Ed). Oxford University Press.\]

## Openness as conditia qua non for transparency

A better approach is, in our opinion, the definition by [Foster](https://www.fosteropenscience.eu), an EU funded project:

> Open Science is the practice of science in such a way that others can collaborate and contribute, where research data, lab notes and other research processes are freely available, under terms that enable reuse, redistribution and reproduction of the research and its underlying data and methods. [Foster](https://www.fosteropenscience.eu/foster-taxonomy/open-science-definition)

To embrace collaboration and contribution in the definition signifies that only access to the products is not enough and automatically includes the requirement that the *whole* research process has to be open to qualify as transparent.

What are the consequences of our insistence in transparent processes in all phases of the research endeavor? Transparency in its own right is crucial for reproducibility, a topic we will have to say a lot more later on. If one takes the double meaning of Open Science seriously, then it includes technology means (e.g., machine processing techniques) as well as behavior adaptation of institutions and scientists (e.g., social changes). If not only the product (the scientific findings) but also the process of knowledge production (the scientific workflow) has to take place without (social, technical, legal, etc.,) barriers, then research data and their interpretation must be transparent in every aspect. It covers the epistemological interest as the starting point, followed up by all kinds of manipulation and reprocessing until the findings get finally published.

## Open Science versus Free or Libre Science

The openness in Open Science is not restricted to public access. Therefore, we cannot translate the term as 'Public Science' without losing some of its meaning. Maybe "open" is the wrong qualifier in the first place? Richard Stallman argues extensively that Open Source is not the same as Free Software (see for instance [What is free software?](https://www.gnu.org/philosophy/free-sw.en.html) or [Why Open Source misses the point of Free Software](https://www.gnu.org/philosophy/open-source-misses-the-point.en.html)). He explains that 'free' is not a matter of price like in "free beer" but of freedom like in "free speech." Looking for a better word, he suggests to use `Libre`; a word borrowed from the French or Spanish language and where there is no confusion between 'free' and 'freedom.' Taken this line of reasoning into account: Perhaps we should also prefer to talk about "Free Science" or even better of "Libre Science" instead of "Open Science"?

Assuming a holistic perspective and taking all mentioned three elements together -- access to the research products, access to the research process and the right (=freedom) to participate or collaborate -- has significant consequences: It calls for a cultural transition with a modified research practice (*Open Research Practice*) and thus a new self-concept as a researcher (*Open Scholarship*). And last not least, we will not only focus on some technical improvements but also on the need to change the power relations in our society.

## Open Science versus Open Knowledge

The English terminology of 'Open Science' has the disadvantage that with 'Science' is meant the natural sciences predominantly. And indeed, the Open Science movement is far more prevalent and entrenched in the [STEM](https://en.wikipedia.org/w/index.php?title=Science,_technology,_engineering,_and_mathematics&oldid=900970900) subjects (Science, Technology, Engineering and Mathematics than in [HASS](https://link.springer.com/content/pdf/10.1007%2Fs10734-009-9265-2.pdf) (Humanities, Arts and Social Sciences) disciplines. As a result of this observation, [Michelle Sidler suggests](https://link.springer.com/chapter/10.1007%2F978-3-319-00026-8_5):

> The movement should thus consider changing its moniker to open knowledge in order to include academic disciplines that do not self-identify as science (2014, 77).

Although we doubt that the meager involvement of HASS in Open Science can be attributed solely to the chosen naming, Sidler's suggestion is appealing for us. Even under the caveat that 'Knowledge' also has a double meaning in English: 'Knowledge' in the general understanding that some knowledge is already acquired and knowledge in the more philosophical sense of insight or discovery. In the first denotation, 'Knowledge' refers to the ownership of a product, in the second to the process of acquisition. However, from our perspective, this is just a desired ambiguity!

## Open Science versus eScience

Another misunderstanding arises from the notions of 'Cyberscience,' 'Science 2.0' and 'eScience.'

Although there are overlaps between Open Science and Science 2.0, we want to emphasize that these two terms are not congruent: Science 2.0 refers to collaborative processes using the so-called Web 2.0 and stresses, therefore, the elements of participation and sharing. It is legitimate to use the notion of 'eScience' when, for instance, researchers work together with appropriate cloud-based software on a scientific contribution. But if the resulting publication is not freely available, then we cannot speak of 'Open Science.'

For Open Science, it is not decisive whether the research process takes place individually or collectively, but whether all activities are transparent and freely available and changeable. Yes, web-based technologies facilitate free availability, access, and transparency, but we should not confuse the possibilities and properties of tools with their final product. (See similar reasoning in Bartling and Friesike 2014, 8^\[Bartling, S., & Friesike, S. (2014). Opening science: The evolving guide on how the internet is changing research, collaboration and scholarly publishing. Springer.\]; Leibniz Research Alliance Science 2.0 2016^\[Leibniz Research Alliance Science 2.0. (2016, May 27). Aim and scope \| Leibniz Research Alliance Science 2.0. Retrieved October 8, 2018, from Leibniz-Forschungsverbund Science 2.0 website: <http://www.leibniz-science20.de/ueber-uns/aufgaben-und-ziele/>\]).

## Wrapping up

We have discussed several elements and approaches to defining Open Science. It turns out that this notion suffers from some inherent and implicit shortcoming. It would be better to use the term 'Libre Knowledge' to avoid possible misunderstandings. But as the concept of 'Libre Knowledge' is not widespread and in common use, for the sake of simplicity we will apply 'Open Knowledge' or even 'Open Science,' but in the broader meaning as we have outlined above.

<span class='Z3988' title='url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Adc&amp;rft.type=blogPost&amp;rft.title=What%20is%20Open%20Science%20About?%20::%20Open%20Science%20Education&amp;rft.source=What%20is%20Open%20Science%20About?&amp;rft.rights=CC%20BY-SA%204.0&amp;rft.description=By%20discussing%20different%20definitions%20of%20%E2%80%98Open%20Science%E2%80%99%20quoted%20in%20the%20literature,%20the%20post%20develops%20a%20particular%20perspective:%20We%20argue%20that%20openness%20must%20include%20not%20only%20scientific%20findings%20but%20also%20the%20process%20of%20knowledge%20creation.%20The%20article%20is%20the%20first%20of%20a%20series%20and%20contrasts%20a%20holistic%20understanding%20of%20Open%20Science%20with%20the%20concepts%20of%20eScience,%20Cyberscience%20or%20Science%202.0,%20Libre%20Science%20and%20Open%20respective%20Libre%20Knowledge.&amp;rft.identifier=https%3A%2F%2Fnotes.peter-baumgartner.net%2F2019%2F06%2F12%2Fwhat-is-open-science-about&amp;rft.aufirst=Peter&amp;rft.aulast=Baumgartner&amp;rft.au=Peter%20Baumgartner&amp;rft.date=&amp;rft.language=en'></span>
