---
title: Advantages of URL shortener
author: Peter Baumgartner
date: '2019-07-23'
categories:
  - app
  - web-service
tags:
  - citation
  - url-shortener
summary: Citing and visiting web addresses with long URLs is sometimes complicated.
  Long URLs are particularly a hardness when there are no clickable links but only
  long strings printed on paper.  This article suggests URL shortener to avoid the
  hurdle mentioned above.
commentable: true
draft: no
slug: advantages-of-url-shortener
---

Citing and visiting web addresses with long URLs is sometimes complicated. Long URLs are particularly a hardness when there are no clickable links but only long strings printed on paper. This article suggests URL shortener to avoid the hurdle mentioned above.

## What is a URL Shortener?[^1]

At first, we need to clarify what an "URL" is. "URL" stands for "Uniform Resource Locator," and they're a way of identifying the location of a file on the internet.

A URL is not the same as a domain name! Sometimes these both terms are confused and used interchangeably. But a domain name is just one part of a URL. The image below shows the difference:

<img src="images/url-parts.png" alt="Parts of an URL" class="border shadow"/>

<figcaption>

<h4>

**Figure 1:** Parts of an Uniform Resource Locator (URL)[^2]

</h4>

</figcaption>

## Use URL shortener for your references

Depending on the Content Management System (CMS) the website is using you can get very long URLs. There are three types of long URLs:

-   **Long pretty URLs:** These URLs consist of understandable text strings. Example: <https://www.dbfk.de/media/docs/expertengruppen/pflegemanagement/DBfK-Handreichung-BAG-Pflegemanagement-Anwerbung-auslaendischer-Mitarbeiter_innen.pdf>
-   **Long ugly URLs:** These URLs include randomly mixed characters, generated automatically by the CMS. Example: <https://www.art.com/gallery/id--c23945/decorative-art-prints.htm?ui=6731D67F76A44083AD1B8F110C4FE301>.
-   **Long mixed URLs:** These URLs contain understandable parts, but these sequences are directed to the CMS and not to humans. Examples are strings for the search engine: <https://www.sfgate.com/search/?action=search&firstRequest=1&searchindex=solr&query=%22earthquake+san+francisco%22>.

The solution for all these kinds of long URLs is the usage of URL shortener. There is a great variety of [URL shortener](https://bit.ly/pb-url-shortener) available. But instead to use the automatic generated short URL (e.g., something like bit.ly/2GIYPa3) use the possibility to edit the URL with an appropriate and memorable word. Although these strings are often longer than the automatically generated short URL, they are much easier to type. Besides, you or other users can even memorize them (e.g., <https://bit.ly/url-shortener>).

As other users of the service also take memorizable short URLs, sometimes there may be a clash of URLs. If this happens, then you are not allowed to generate this specific URL. To prevent colliding URLs, I use a short prefix referring to me as the author or to the subject/project of the URL (e.g., <https://bit.ly/pb-url-shortener>).

## Summary

You might be thinking that shortening your URL is an extra step, but URL shorteners are very beneficial:

-   Short URLs are more comfortable to share
-   Short URLs are essential if there is limited space (e.g., Twitter)
-   Short URLs are more visually appealing
-   Short URLs are memorized easier
-   Short URLs are more straightforward to type when there is only a paper reference
-   Short URL services can provide additional information such as the number of clicks
-   Short URLs can be adjusted if the original URL changes, so that users still have the correct links
-   Short URLs services allow you sometimes to create your brand and categories for your URLs. If they do not provide this service, you can use prefixes to get some rudimentary management for your URLs
-   Short URLs prevent line breakings (e.g., in emails) so that the user does not have to cut and paste to put the link together

But there is also a disadvantage of URL shortener:[^2] They are often used by spammers to hide the URL destination. That way, unsuspecting people are more likely to click on them.

## Wakelet

In addition to the following [Wakelet](https://wakelet.com/), there is also a [community edition on my Wakelet homepage](https://wakelet.com/@PeterBaumgartner) where you can add relevant links.

<iframe class="wakeletEmbed" width="100%" height="760px" src="https://embed.wakelet.com/wakes/5f48327e-dc0b-4a33-96cc-02fed51173dc/list" style="border: none" allow="autoplay">

</iframe>

<script src="https://embed-assets.wakelet.com/wakelet-embed.js" charset="UTF-8"></script>

[^1]: I took the next two paragraphs from [Oberlo](https://www.oberlo.com/blog/best-url-shorteners) and modified them slightly.

[^2]: I took the next two sentences from [Oberlo](https://www.oberlo.com/blog/best-url-shorteners).
