---
title: "Educational Tools and Learning Theory"
author: "Peter Baumgartner"
date: '2020-01-12'
lastmod: '2021-05-20'
categories:
- edTech
- learning-theory
tags:
- educational-design
- taxonomy
summary: 'This article suggests a procedure to categorize the enormous amount
  of educational tools in the market. My approach uses a framework of three well-grounded
  learning theories: Instruction, Cognition, and Construction based on presentation
  modes (one-way teaching), dialog settings (two-way education), and collaborative
  scenarios (learning by mastering complex situations). As a proof of concept, I will
  use the [Top Tools for Learning](https://www.toptools4learning.com/) (TT4L), compiled
  by [Jane Hart](https://www.toptools4learning.com/jane-hart/) as a result of the 13th Annual Learning Tools Survey (published 18. September 2019).'
commentable: true
draft: no
slug: educational-tools-and-learning-theory
image:
  placement: 2    
  caption: "[Top 100 Tools for Personal Learning 2020. By Jane Hart](https://www.toptools4learning.com/wp-content/uploads/2020/08/tt4l2020pl-624x468.jpg)"
  alt_text: "Map of Logoi from Top 100 Tools organized around broad categories."
  focal_point: "Center"
  preview_only: false
---

{{< figure src="images/2019-C4LPT-categorization-min.png" class="border shadowed floatright" alt="Categories of tools by Jane Hart" >}}

This article suggests a procedure to categorize the enormous amount of educational tools in the market. My approach uses a framework of three well-grounded learning theories: Instruction, Cognition, and Construction based on presentation modes (one-way teaching), dialog settings (two-way education), and collaborative scenarios (learning by mastering complex situations). As a proof of concept, I will use the [Top Tools for Learning](https://www.toptools4learning.com/) (TT4L), compiled by [Jane Hart](https://www.toptools4learning.com/jane-hart/) as a result of the 13th Annual Learning Tools Survey (published 18 September 2019).

Inspired by the yearly ranking of [Top Tools for Learning](https://www.toptools4learning.com/) (TT4L) compiled by Jane Hart, I wanted to know if there are global changes or trends in e-learning over the years. The ranked list of tools goes back 13 years and is available for all past years via the [Wayback Machine](https://archive.org/web/web.php). As a plan for analysis and for presenting results, I imagine a similar procedure as I have used in [comparing static website generators](/2019/08/01/comparing-website-generators-over-time/) over the years.

## Inconsistencies in Jane's categories

To compare the different rankings of the educational tools, I will need a classification of all apps/web services based on pedagogical reasons. For my purposes, the [categorizations used by Jane Hart](http://c4lpt.co.uk/directory-of-learning-performance-tools/) (see right column) is not useful:

-   It is the functionality of the tool itself, which motivates her division in different classes primarily. Therefore all categories contain the word 'tool' in their name. She distinguishes four main types:

    1.  Instructional tools
    2.  Content development tools
    3.  Social tools
    4.  Personal (and professional) tools

-   Her sub-categorization under the four main headings is not consistent and has changed over the years. Sometimes she uses 'Content' as a fifth type, or she includes 'professional' under the heading of 'personal tool.'

-   Some tools are platform-dependent (e.g., Sharepoint, Keynote).

-   Even proprietary name for hardware is ranked in her list (e.g., iPhone, iPad, SMART board instead of smartphone, tablet, whiteboard).

Another much better division can be drawn from her [beautiful infographics](https://www.toptools4learning.com/edu100/) (see below) on top tools for higher education 2019. Here Hart distinguishes by pedagogical reasons between

-   Didactics (Formal Learning)
-   Discovery (Informal Learning)
-   Discourse (Social Learning) and
-   Doing (Studying).

Aside from the fact that 'formal' and 'informal learning' has another meaning (see the definition by the [Council of Europe](https://www.coe.int/en/web/lang-migrants/formal-non-formal-and-informal-learning) on formal, non-formal, and informal learning). I do not understand why 'studying' is different from structured learning in an academic setting. And why should 'studying' be linked just with the doing-bubble?

{{< figure src="images/2019-C4LPT-HE-categorization-min.png" class="border shadowed" alt="Infographics on the usage of the top tools for higher education in 2019" title="Usage of top tools for higher edudation in 2019. Infographics by C4LPT (2019): https://www.toptools4learning.com/edu100/." >}}

## Developing educational motivated categories

{{< figure src="images/learning-modes-min.png" class="border shadowed floatright" alt="Infographics: Three different learning/teaching modes" title="Three different learning/teaching modes. Infographics by Peter Baumgartner (2018)" >}}

Without going here into detail, I will use my categorization of learning theories published among others in The Zen Art of Teaching ([PDF](http://peter.baumgartner.name/wp-content/uploads/2012/12/Baumgartner_2004_The-Zen-Art-of-Teaching.pdf), 545 kB). This article outlines three different kinds of teaching modes:

-   **Instruction or Learning I**: Using static learning materials for reading, listening, and watching.
-   **Cognition or Learning II**: Using dynamic and elaborated didactical educational interactions for guided practice.
-   **Construction or Learning III**: Using collaborative scenarios for mastering unstructured situations.

This categorization results in different educational aspects for each of the three teaching/learning modes:

-   **Kind of knowledge acquisition**: static --dynamic/procedural -- social.
-   **Teaching modes**: transfer -- dialog/discussion -- collaboration.
-   **Learning strategies**: study -- practice -- mastering.
-   **Assessment methods**: correct answers -- applying adequate techniques, processes, and procedures -- success criteria.
-   **Teaching strategies**: explaining -- observing and helping -- collaborating.

Even though my suggestion is coarse-grained as it distinguishes only three types, it has to overcome several problems of operationalizations:

### One tool -- several functionalities

Sometimes it is not easy to classify tools unambiguously into one of the three categories. Modern tools incorporate many features that may address different types of learning modes. Take, for example, the use of a learning management system (LMS). You can use it for various activities (reading PDFs, work through quizzes, or writing collaboratively into a wiki). In those inconclusive situations, I will utilize the highest predominant functionality of the tools. 'Highest' means that *Learning II* is more elevated than *Learning I*. This is not a quality rating of the different learning modes as all three modes have their value under certain conditions. 'Higher' or 'lower' address here the complexity of student activities.

But what is the 'predominant functionality' of a tool? I assume that every educational technology, every technology-supported learning environment, or internet application, implement a theoretical learning model -- irrespective of opinions and beliefs of developers and teachers. In the case of LMS dominates guided learning interactivity (*Learning II*). Although teachers may use tools ingeniously for purposes not foreseen from the developers, I think that these inventing teaching strategies are not the mainstream.

Following other users on the web with the same subject interests, getting in contact with them, commenting their blogs, etc. entitles for *Learning II* but does **not** qualify for *Learning III*. I will rate only rate an educational setting as *Learning III* if learners produce (individually or collaboratively) an artifact for learning purposes.

### General tools not intended primarily for education

In Jane Hart's list of top tools are many products and web services not primarily developed for education, like word processors, email clients, file-sharing platforms, note-taking applications, browsers, search engines, etc. The reason for this broad mixture is the content of the questionnaire and their target group. Not learners or teachers, but mainly IT professionals and learning designers, addresses the survey. This orientation leads to two biases, as mentioned by Jane Hart:

-   only 22% of voters came from colleges and universities, hence the Top 200 list is therefore skewed towards workplace learning.
-   since only 6% of respondents came from schools, the EDU100 list this year focuses on tools for Higher Education.

{{< figure src="images/survey-TT4L-min.png" class="border shadowed floatright" alt="Snippet of the survey form for compiling the top tool list for 2020" title="Snippet of survey form for compiling the top tool list for 2020" >}}

Another issue favoring general tools are the questions themselves. See, for instance, the [voting form for 2020](https://www.toptools4learning.com/voting/) on the right ahnd side of this article:

> A valid entry needs to include 10 different DIGITAL tools (resources, services, etc) -- listed in any order (emphasis not mine).

So the questions ask for **digital** tools, not for digital **educational** tools. The consequence is that the top list with a few exceptions **does not include subject-oriented software** (e.g., apps for learning math, science, languages). This bias is an essential drawback as many e-learning scenarios use these kinds of content-related software.

The other side of the same coin is that there is a bias towards personal knowledge management applications. Software like email clients, browsers, search engines, etc., are unquestionably also essential parts of a learning ecology. Using these tools always goes together with (informal) learning experiences. But an educational taxonomy of tools for education should focus on apps or web services developed for e-learning. To distinguish those personal productivity instruments from tools explicitly dedicated to learning, I have designated them with *Learning 0*. Under this category, I also have classified support tools like converters or 'neutral' web resources like portals for icons, images, or other material.

Summarizing this subsection is the following types of tools designated with *Learning 0*:

-   General productivity: Word processors, email clients, browsers, search engines, converters, translators, grammar checkers, image/icon/theme libraries, and other supporting tools.
-   Personal knowledge management: Note-taking software, calendars, project management, skill validation.
-   Hardware: Smartphones, tablets, interactive whiteboards.

### Developing learning material or using it?

Another complication arises from the fact that the educational judgment of developer tools can be seen two-fold:

-   from the authoring perspective, e.g., the resource development view
-   from the angle of using the developed product

There are content development tools which can be used by learner and teacher alike. Those apps or web services with various perspectives (e.g., blog services, screen-casting, curation tools) I will classify from their ownership. If it is easily possible that students get their personal instance, then I will designate it as *Learning III*.

With 'easy' I mean

-   that it is free available at least in a freemium variant for personal usage. This definition of 'free available' does not apply if learners are entitled to free usage only via an institutional account.
-   that it is easy to install either through the download of packaged software without any special additional technical requirements, such as using the terminal or running a server, changing functionality programmatically, or only through a simple online registration).
-   that it can be used easily in educational settings (no specialized knowledge necessary, learn time only 1-2hrs, no specialized hardware, platform-independent).

Note that every case has to be judged individually. For a correct classification with the mentioned rules, one has to look into pricing models, installation procedures, user interface, and typical application patterns.

## Conclusion

To summarize my suggestion for an educational categorization of digital tools, I will define four types of apps, respectively web services:

-   **Learning 0**: Tools supporting personal knowledge management, productivity, and portals for web resources.
-   **Learning I**: Transfer of knowledge. The focus of learner engagement is primarily oriented to content to acquire factual knowledge.
-   **Learning II**: Applying knowledge, practicing procedures. The emphasis here is learner interactivity with dynamic content and dialog with teacher and co-learner.
-   **Learning III**: Collaboratively solving challenges. Essential is producing a useful output, doing something creatively and cooperatively.
-   **Learning IV**: Multi-purpose tool with features for Learning III **and** either Learning 0 or Learning I.

... to be continued

{{% callout note %}} Update 2021-05-20: Originally, I have planned to reorganize Jane Hart's data according to my set of categories. But unfortunately, because of other priorities, I didn't have time so far. But the follow-up of this post is still on my schedule. {{% /callout %}}

<span class='Z3988' title='url_ver=Z39.88-2004&amp;ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fzotero.org%3A2&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Adc&amp;rft.type=blogPost&amp;rft.title=Educational%20Tools%20and%20Learning%20Theory&amp;rft.source=Thought%20splinters&amp;rft.rights=CC%20BY-SA%204.0&amp;rft.description=This%20article%20suggests%20a%20procedure%20to%20categorize%20the%20enormous%20amount%20of%20educational%20tools%20in%20the%20market.%20My%20approach%20uses%20a%20framework%20of%20three%20well-grounded%20learning%20theories:%20Instruction,%20Cognition,%20and%20Construction%20based%20on%20presentation%20modes%20(one-way%20teaching),%20dialog%20settings%20(two-way%20education),%20and%20collaborative%20scenarios%20(learning%20by%20mastering%20complex%20situations).%20As%20a%20proof%20of%20concept,%20I%20will%20use%20the%20[Top%20Tools%20for%20Learning](https://www.toptools4learning.com/)%20(TT4L),%20compiled%20by%20[Jane%20Hart](https://www.toptools4learning.com/jane-hart/)%20as%20a%20result%20of%20the%2013th%20Annual%20Learning%20Tools%20Survey%20(published%2018.%20September%202019).&amp;rft.identifier=https%3A%2F%2Fnotes.peter-baumgartner.net%2F2020%2F01%2F12%2Feducational-tools-and-learning-theory&amp;rft.aufirst=Peter&amp;rft.aulast=Baumgartner&amp;rft.au=Peter%20Baumgartner&amp;rft.date=2020-01-12&amp;rft.language=en'></span>
